@@ -20,15 +20,15 @@ if __name__ == '__main__':
     # the paths already
     sys.path.insert(0, os.path.abspath(os.path.join(os.pardir, os.pardir)))
 
-import pytz
-from pytz import reference
-from pytz.tzfile import _byte_string
-from pytz.tzinfo import DstTzInfo, StaticTzInfo
+import pytz  # noqa
+from pytz import reference  # noqa
+from pytz.tzfile import _byte_string  # noqa
+from pytz.tzinfo import DstTzInfo, StaticTzInfo  # noqa
 
 # I test for expected version to ensure the correct version of pytz is
 # actually being tested.
-EXPECTED_VERSION = '2018.9'
-EXPECTED_OLSON_VERSION = '2018i'
+EXPECTED_VERSION = '2020.1'
+EXPECTED_OLSON_VERSION = '2020a'
 
 fmt = '%Y-%m-%d %H:%M:%S %Z%z'
 
@@ -183,8 +183,14 @@ class PicklingTest(unittest.TestCase):
         # Python 3 introduced a new pickle protocol where numbers are stored in
         # hexadecimal representation. Here we extract the pickle
         # representation of the number for the current Python version.
-        old_pickle_pattern = pickle.dumps(tz._utcoffset.seconds)[3:-1]
-        new_pickle_pattern = pickle.dumps(new_utcoffset)[3:-1]
+        #
+        # Test protocol 3 on Python 3 and protocol 0 on Python 2.
+        if sys.version_info >= (3,):
+            protocol = 3
+        else:
+            protocol = 0
+        old_pickle_pattern = pickle.dumps(tz._utcoffset.seconds, protocol)[3:-1]
+        new_pickle_pattern = pickle.dumps(new_utcoffset, protocol)[3:-1]
         hacked_p = p.replace(old_pickle_pattern, new_pickle_pattern)
 
         self.assertNotEqual(p, hacked_p)
@@ -758,6 +764,18 @@ class CommonTimezonesTestCase(unittest.TestCase):
         self.assertFalse('Europe/Belfast' in pytz.common_timezones_set)
 
 
+class ZoneCaseInsensitivityTestCase(unittest.TestCase):
+    def test_lower_case_timezone_constructor_arg(self):
+        for tz in pytz.all_timezones_set:
+            from_lower = pytz.timezone(tz.lower())
+            from_passed = pytz.timezone(tz)
+            self.assertEqual(from_lower,
+                             from_passed,
+                             "arg '%s' and arg '%s' produce different "
+                             "timezone objects" % (
+                                 from_lower, from_passed))
+
+
 class BaseTzInfoTestCase:
     '''Ensure UTC, StaticTzInfo and DstTzInfo work consistently.
 
@@ -841,6 +859,7 @@ def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(doctest.DocTestSuite('pytz'))
     suite.addTest(doctest.DocTestSuite('pytz.tzinfo'))
+    suite.addTest(doctest.DocTestSuite('pytz.exceptions'))
     import test_tzinfo
     suite.addTest(unittest.defaultTestLoader.loadTestsFromModule(test_tzinfo))
     return suite
